@@ -943,7 +943,9 @@ Following headline properties can determine the mail headers.
 
       ;; Display BUFFER
       (if org-mime-obey-display-buffer-p
-          (switch-to-buffer (display-buffer buffer))
+          (progn
+            (display-buffer buffer)
+            (switch-to-buffer buffer))
         (delete-other-windows)
         (org-switch-to-buffer-other-window buffer))))))
 
